/*********************************************************************************
**
**   $Id: main.cpp,v 1.17 2004/06/08 11:34:53 croftj Exp $
**   Copyright (c) 2004 Joe Croft <joe@croftj.net>
**   
**   This file is part of ah2.
**
**   ah2 is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
**   Foobar is distributed in the hope that it will be useful,
**   but WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**   GNU General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with Foobar; if not, write to the Free Software
**   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*********************************************************************************/

#include <qaccel.h>
#include <qapplication.h>
#include <qdir.h>
#include <qfont.h>
#include <qkeysequence.h>
#include <qmenubar.h>
#include <qnamespace.h>
#include <qpopupmenu.h>
#include <qregexp.h>
#include <qsettings.h>

#include "InvoiceWindow.h"
#include "loginform.h"

QSettings Config;
InvoiceWindow *mw;

QApplication *a;
QStringList Reports;

static QPopupMenu *makeReportMenu()
{
   QPopupMenu *rptMenu = new QPopupMenu;
   QDir rptDir(Config.readEntry("/CroftJ/AutoHouse/ReportDirectory", "/opt/ah2/reports"));
   printf("Searching for reports in %s\n", (const char*)rptDir.absPath());


   Reports.clear();
   if ( rptDir.exists() ) 
   {
      printf("Directory exists\n");
      QStringList rpts = rptDir.entryList("rpt*.pl", QDir::Files);
      QStringList::Iterator it;
      int ofs = 0;

      for (it = rpts.begin(); it != rpts.end(); it++) 
      {
         QString fn = rptDir.absPath() + QString("/");
         fn += (*it);
         printf("Have report file '%s'\n", (const char*)fn);
         
         QFile rf(fn);
         if ( rf.open(IO_ReadOnly) ) 
         {
            QString line;
            QRegExp re(QString("^#([a-z]+):(.*):"));
            re.setMinimal(true);
            while (rf.readLine(line, 256) >= 0) 
            {
               printf("Report Line: %s", (const char*)line);
               if (re.search(line) >= 0)
               {
                  QString cmd       = re.cap(1);
                  QString text      = re.cap(2);
                  QString arg_name  = re.cap(3);
                  QString ctl_type  = re.cap(4);
                  QString options   = re.cap(5);
                  printf("Found command: |%s|\n", (const char*)cmd);
                  if ( cmd == "title" ) 
                  {
                     printf("Have report: |%s|\n", (const char*)text);
                     Reports.append(fn);
                     rptMenu->insertItem(text, ofs++);
                     break;
                  }
               }
            }
            rf.close();
         }
      }
   }
   return(rptMenu);
}

int main( int argc, char ** argv )
{
   a = new QApplication( argc, argv );
   QString font = Config.readEntry("/CroftJ/AutoHouse/Font");
   printf("config font string: %s\n", (const char*)font);
   fflush(stdout);
   QRegExp re("(.+)::(.+)::(.+)::(.+)");
   re.setMinimal(true);
   re.search(font);
   QString family = re.cap(1);
   QString style = re.cap(2);
   QString pointsize = re.cap(3);
   QString italics = re.cap(4);
   printf("Setting font: %s::%s::%s::%s\n", (const char*)family, (const char*)style, (const char*)pointsize, (const char*)italics);
   fflush(stdout);

   QFont f(family, pointsize.toInt(), style.toInt(), italics.toInt());
   a->setFont(f);
   LoginForm *login = new LoginForm();
   login->initialize();
   if (login->exec()) 
   {
      mw = new InvoiceWindow;

      QPopupMenu *fileMenu = new QPopupMenu;
      fileMenu->insertItem("Data Dump", mw, SLOT(dataDump()));
      fileMenu->insertItem("Data Restore", mw, SLOT(dataRestore()));
      fileMenu->insertSeparator();
      fileMenu->insertItem("Exit", mw, SLOT(close()));
      QPopupMenu *workorderMenu = new QPopupMenu;
//      workorderMenu->insertItem("New Work Order", mw, SLOT(createWorkOrder()));
      workorderMenu->insertItem("New Work Order", mw, SLOT(createWorkOrder()), Qt::Key_Insert);
//      workorderMenu->insertItem("Open Work Order", mw, SLOT(openWorkOrder()));
      workorderMenu->insertItem("Open Work Order", mw, SLOT(openWorkOrder()), Qt::Key_F10);
      workorderMenu->insertItem("Clear Work Order", mw, SLOT(clearForm()), Qt::Key_F12);
      workorderMenu->insertSeparator();
      workorderMenu->insertItem("Print Work Order", mw, SLOT(printWorkOrder()), Qt::Key_Print);
      workorderMenu->insertItem("Close Work Order", mw, SLOT(closeWorkOrder()));
      workorderMenu->insertItem("Delete Work Order", mw, SLOT(deleteWorkOrder()));
      workorderMenu->insertSeparator();
      workorderMenu->insertItem("Edit/Add &Parts", mw, SLOT(addWOParts()), Qt::ALT + Qt::Key_P);
      workorderMenu->insertItem("Edit/Add &Labor", mw, SLOT(addWOLabor()), Qt::ALT + Qt::Key_L);
      workorderMenu->insertItem("Edit/Add &Job", mw, SLOT(addParts()), Qt::ALT + Qt::Key_J);
      QPopupMenu *editMenu = new QPopupMenu;
      editMenu->insertItem("Customers", mw, SLOT(editCustomers()));
      editMenu->insertItem("Vehicles", mw, SLOT(editVehicles()));
      editMenu->insertItem("Rates", mw, SLOT(editRates()));
      editMenu->insertItem("Invoice Settings", mw, SLOT(editBizInfo()));
      editMenu->insertItem("Font", mw, SLOT(configureFont()));
      QPopupMenu *viewMenu = new QPopupMenu;
      QPopupMenu *rptMenu = makeReportMenu();
      a->connect(rptMenu, SIGNAL(activated(int)), mw, SLOT(doReport(int)));
      QPopupMenu *acctMenu = new QPopupMenu;
      acctMenu->insertItem("Move Workorders", mw, SLOT(moveWorkOrders()));
      acctMenu->insertItem("Start Accounting", mw, SLOT(startAccounting()));

      QPopupMenu *inventoryMenu = new QPopupMenu;
      inventoryMenu->insertItem("Vendors", mw, SLOT(editVendors()));
      inventoryMenu->insertItem("Parts", mw, SLOT(editParts()));

      QMenuBar *mb = new QMenuBar(mw);
      mb->insertItem("&File", fileMenu);
      mb->insertItem("&Work", workorderMenu);
      mb->insertItem("&Edit", editMenu);
      mb->insertItem("&View", viewMenu);
      mb->insertItem("&Reports", rptMenu);
      mb->insertItem("&Inventory", inventoryMenu);
      mb->insertItem("&Accounting", acctMenu);

      mw->show();
      mw->showMaximized();
      a->connect( a, SIGNAL( lastWindowClosed() ), a, SLOT( quit() ) );
      return a->exec();
   }
}


